@@ -67,6 +67,9 @@ TournamentSize=xegaSelectGene::parm(2),
 GeneMap=xegaGaGeneMapFactory(method="Bin2Dec"),
 SelectGene=xegaSelectGene::SelectGeneFactory(method="Proportional"),
 SelectMate=xegaSelectGene::SelectGeneFactory(method="Uniform"),
+Accept=function(op, gene, lF) {op(gene, lF)},
+ReportEvalErrors=function() {TRUE},
+Pipeline=xegaSelectGene::parm(FALSE),
 InitGene=xegaGaInitGene,
 DecodeGene=xegaGaDecodeGene,
 EvalGene=xegaSelectGene::EvalGeneFactory(method="EvalGeneU"),
